declare namespace JinghuanWx {
    type Request<T, T2> = (params: T) => Promise<T2>;

    type WeixinPayOption = {
        wx_app_id: string;
        wx_mch_id: string;
        wx_pay_key: string;
        wx_app_secret: string;
        wx_cert_path: string;
        wx_key_path: string;
        wx_pfx_path: string;
    }

    type WeixinWorkOption = {}

    type method = "POST" | "GET";

    class BizMsgCrypt {
        constructor(token: string, encodingAesKey: string, corpid: string);

        decryptMsg(msgSignature: string, timestamp: string, nonce: string, postData: string): Promise<Object>

        encryptMsg(replyMsg: string, timeStamp: string, nonce: string): Promise<string>;

        VerifyURL(msgSignature: string, timestamp: string, nonce: string, echoStr: string): Promise<string>
    }

    type attrs = {
        name: string,
        value: string
    }

    type external_attr = {
        type: number,
        name: string,
        text: {
            value: string
        },
        web: {
            url: string,
            title: string
        },
        miniprogram: {
            appid: string,
            pagepath: string,
            title: string
        }
    }

    type userlist = {
        userid: string,
        name: string,
        department: Array<number>,
        order: Array<number>,
        position: string,
        mobile: string,
        gender: string,
        email: string,
        isleader: number,
        avatar: string,
        telephone: string,
        enable: number,
        alias: string,
        status: number,
        extattr: { attrs: Array<attrs> },
        qr_code: string,
        external_position: string,
        external_profile: {
            external_attr: Array<external_attr>
        }
    }

    type button = Array<{
        type: string
        name: string
        key: string
        url: string
        sub_button: Array<{
            type: string
            name: string
            key: string
            url: string
        }>
    }>;

    type department = {
        id: number
        name: string
        parentid: number
        order: number
    }

    type Utils = {
        BizMsgCrypt: BizMsgCrypt
    }

    class WeixinWorkClient {
        constructor(option: WeixinWorkOption, ctx: object);

        execute(WeixinWorkRequest: WeixinWorkRequest): Promise<object>;
    }

    class WeixinWorkRequest {
        constructor(option: WeixinWorkOption, ctx: object, params: object);

        file: string;
        fields: Array<string>;
        gatewayUrl: string;
        method: method
        ctx: object;
        option: object;

    }

    class WeixinWork {
        constructor(option: WeixinWorkOption, ctx: object);

        ctx: object;
        option: object;

        AgentGetRequest: Request<{
            access_token: string
            agentid: string
        }, {
            errcode: number
            errmsg: string
            agentid: number
            name: string
            square_logo_url: string
            description: string
            allow_userinfos: {
                user: Array<{
                    userid: string
                }>
            }
            allow_partys: {
                partyid: Array<number>
            }
            allow_tags: {
                tagid: Array<number>
            }
            close: number
            redirect_domain: string
            report_location_flag: string
            isreportenter: string
            home_url: string
        }>;

        AgentListRequest: Request<{
            access_token: string
        }, {
            errcode: number
            errmsg: string
            agentlist: Array<{
                agentid: number
                name: string
                square_logo_url: string
            }>
        }>;

        AgentSetRequest: Request<{
            access_token: string
            agentid: number
            report_location_flag: number
            logo_mediaid: string
            name: string
            description: string
            redirect_domain: string
            isreportenter: string
            home_url: string
        }, {
            errcode: number
            errmsg: string
        }>;

        BatchGetresultRequest: Request<{
            access_token: string
            jobid: string
        }, {
            errcode: number
            errmsg: string
            status: number
            type: string
            total: number
            percentage: number
            result: Array<{
                userid: string
                errcode: 0
                errmsg: string
            } | {
                action: number
                partyid: number
                errcode: number
                errmsg: string
            }>;
        }>;

        BatchInviteRequest: Request<{
            access_token: string
            user: Array<string>
            party: Array<number>
            tag: Array<number>
        }, {
            errcode: number
            errmsg: string
            invaliduser: Array<string>
            invalidparty: Array<number>
            invalidtag: Array<number>
        }>;

        BatchReplacepartyRequest: Request<{
            access_token: string
            media_id: string
            callback: {
                url: string
                token: string
                encodingaeskey: string
            }
        }, {
            errcode: number
            errmsg: string
            jobid: string
        }>;

        BatchReplaceuserRequest: Request<{
            access_token: string
            media_id: string
            callback: {
                url: string
                token: string
                encodingaeskey: string
            }
        }, {
            errcode: number
            errmsg: string
            jobid: string
        }>;

        BatchSyncuserRequest: Request<{
            media_id: string,
            to_invite: boolean,
            callback:
                {
                    url: string,
                    token: string,
                    encodingaeskey: string
                }
        }, {
            errcode: number
            errmsg: string
            jobid: string
        }>;

        CrmGetExternalContactRequest: Request<{
            access_token: string
            external_userid: string
        }, {
            errcode: number
            errmsg: string
            external_contact: {
                external_userid: string
                name: string
                position: string
                avatar: string
                corp_name: string
                corp_full_name: string
                type: number
                gender: number
                unionid: string
                external_profile: {
                    external_attr: Array<{
                        type: number
                        name: string
                        text: {
                            value: string
                        }
                        web: {
                            url: string
                            title: string
                        }
                        miniprogram: {
                            appid: string
                            pagepath: string
                            title: string
                        }
                    }>
                }
                follow_user: Array<{
                    userid: string
                    remark: string
                    description: string
                    createtime: number
                }>
            }
        }>

        DepartmentCreateRequest: Request<{
            access_token: string
            id: number
            name: string
            parentid: number
            order: number
        }, {
            errcode: number
            errmsg: string
        }>;

        DepartmentDeleteRequest: Request<{
            access_token: string
            id: number
        }, {
            errcode: number
            errmsg: string
        }>;

        DepartmentListRequest: Request<{
            access_token: string
            department_id: number
            fetch_child: number
        }, {
            errcode: number
            errmsg: string,
            department: Array<department>
        }>;

        DepartmentUpdateRequest: Request<{
            access_token: string
            id: number
        }, {
            errcode: number
            errmsg: string
        }>;

        GetTokenRequest: Request<{
            corpid: string
            corpsecret: string
        }, {
            errcode: number
            errmsg: string
            access_token: string
            expires_in: number
        }>;

        MediaGetRequest: Request<{
            access_token: string
            media_id: string
        }, {}>;

        MediaUploadRequest: Request<{
            access_token: string
            type: string
        }, {
            errcode: number
            errmsg: string
            type: string
            media_id: string
            created_at: number
        }>;

        MenuCreateRequest: Request<{
            access_token: string
            agentid: string
            button: button
        }, {
            errcode: number
            errmsg: string
        }>;

        MenuDeleteRequest: Request<{
            access_token: string
            agentid: number
        }, {
            errcode: number
            errmsg: string
        }>;

        MenuGetRequest: Request<{
            access_token: string
            agentid: string
        }, button>;

        MessageSendRequest: Request<{
            access_token: string
        }, {
            touser: string
            toparty: string
            totag: string
            msgtype: string
            agentid: number
            text: {
                content: string
            }
            safe: number
            image: {
                media_id: string
            }
            voice: {
                media_id: string
            }
            video: {
                media_id: string
                title: string
                description: string
            }
            file: {
                media_id: string
            }
            textcard: {
                title: string
                description: string
                url: string
                btntxt: string
            }
            news: {
                articles: Array<{
                    title: string
                    description: string
                    url: string
                    picurl: string
                }>
            }
            mpnews: {
                articles: Array<{
                    title: string
                    thumb_media_id: string
                    author: string
                    content_source_url: string
                    content: string
                    digest: string
                }>
            }
            miniprogram_notice: {
                appid: string
                page: string
                title: string
                description: string
                emphasis_first_item: string
                content_item: Array<{
                    key: string
                    value: string
                }>
            }
        }>;

        TagAddtagusersRequest: Request<{
            access_token: string
            tagid: number
            userlist: Array<string>
            partylist: string
        }, {
            errcode: number
            errmsg: string
            invalidlist: string
            invalidparty: Array<number>
        }>;

        TagCreateRequest: Request<{
            access_token: string
            tagname: string
            tagid: number
        }, {
            errcode: number
            errmsg: string
            tagid: number
        }>;

        TagDeleteRequest: Request<{
            access_token: string
            tagid: number
        }, {
            access_token: number
            errmsg: string
        }>;


        TagDeltagusersRequest: Request<{
            access_token: string
            tagid: number
            userlist: Array<string>
            partylist: Array<number>
        }, {
            errcode: number
            errmsg: string
            invalidlist: string
            invalidparty: Array<number>
        }>;


        TagGetRequest: Request<{
            access_token: string
            tagid: number
        }, {
            errcode: number
            errmsg: string
            tagname: string
            userlist: Array<{
                userid: string
                name: string
            }>
            partylist: Array<number>
        }>;

        TagListRequest: Request<{
            access_token: string
        }, {
            errcode: number
            errmsg: string
            taglist: Array<{
                tagid: number
                tagname: string
            }>
        }>;

        TagUpdateRequest: Request<{
            access_token: string
            tagid: number,
            tagname: string
        }, {
            errcode: number
            errmsg: string
        }>;

        UserBatchdeleteRequest: Request<{
            access_token: string
            useridlist: Array<string>
        }, {
            errcode: number
            errmsg: string
        }>;

        UserConvertToOpenidRequest: Request<{
            access_token: string
            userid: string
        }, {
            errcode: number
            errmsg: string
            openid: string
        }>;

        UserConvertToUseridRequest: Request<{
            access_token: string
            openid: string
        }, {
            errcode: number
            errmsg: string
            userid: string
        }>;


        UserCreateRequest: Request<{
            access_token: string
            userid: number
            name: string
            alias: string
            mobile: string
            department: Array<number>
            order: Array<number>
            position: string
            gender: "1" | "2"
            email: string
            telephone: string
            isleader: boolean
            avatar_mediaid: string
            enable: boolean
            extattr: { attrs: Array<attrs> }
            to_invite: boolean
            external_profile: string
            external_position: {
                external_attr: external_attr
            }
        }, {
            errcode: number
            errmsg: string
        }>;


        UserDeleteRequest: Request<{
            access_token: string
            userid: string
        }, {
            errcode: number
            errmsg: string
        }>;


        UserGetRequest: Request<{
            access_token: string
            userid: string
        }, {
            errcode: number,
            errmsg: string,
            userid: string,
            name: string,
            department: Array<number>,
            order: Array<number>,
            position: string,
            mobile: string,
            gender: string,
            email: string,
            isleader: number,
            avatar: string,
            telephone: string,
            enable: number,
            alias: string,
            status: number,
            extattr: { attrs: Array<attrs> },
            qr_code: string,
            external_position: string,
            external_profile: {
                external_attr: Array<external_attr>
            }
        }>;


        UserGetuserinfoRequest: Request<{
            access_token: string
            code: string
        }, {
            errcode: number
            errmsg: string
            UserId: string
            DeviceId: string
            user_ticket: string,
            expires_in: string,
            OpenId: string
        }>;


        UserListRequest: Request<{
            access_token: string,
            department_id: string,
            fetch_child: string
        }, {
            errcode: number,
            errmsg: string,
            userlist: Array<{
                userid: string,
                name: string,
                department: Array<number>,
                order: Array<number>,
                position: string,
                mobile: string,
                gender: string,
                email: string,
                isleader: number,
                avatar: string,
                telephone: string,
                enable: number,
                alias: string,
                status: number,
                extattr: { attrs: Array<attrs> },
                qr_code: string,
                external_position: string,
                external_profile: {
                    external_attr: Array<external_attr>
                }
            }>
        }>;


        UserSimplelistRequest: Request<{
            access_token: string
            department_id: string
            fetch_child: string
        }, {
            errcode: number
            errmsg: string
            userlist: Array<userlist>
        }>;


        UserUpdateRequest: Request<{
            access_token: string,
            userid: string,
            name: string,
            department: Array<number>,
            order: Array<number>,
            position: string,
            mobile: string,
            gender: string,
            email: string,
            isleader: number,
            enable: number,
            avatar_mediaid: string,
            telephone: string,
            alias: string,
            extattr: { attrs: Array<attrs> },
            external_position: string,
            external_profile: {
                external_attr: Array<external_attr>
            }
        }, {
            errcode: number,
            errmsg: string
        }>;


        GetJsapiTicketRequest: Request<{
            access_token: string
        }, {
            errcode: number,
            errmsg: string,
            ticket: string,
            expires_in: number
        }>


        AppchatCreateRequest: Request<{
            access_token: string,
            name?: string
            owner?: string
            userlist?: Array<string>
            chatid?: string
        }, {
            errcode: number
            errmsg: string,
            chatid: string
        }>

        AppchatUpdateRequest: Request<{
            access_token: string,
            chatid: string,
            name: string
            owner?: string
            add_user_list?: Array<string>
            del_user_list?: Array<string>
        }, {
            errcode: number
            errmsg: string,
        }>

        AppchatGetRequest: Request<{
            access_token: string,
            chatid: string
        }, {
            errcode: number
            errmsg: string,
            chat_info: {
                chatid: string
                name: string
                owner: string
                userlist: Array<string>
            }
        }>

        AppchatSendRequest: Request<{
            access_token: string
        }, {
            errcode: number
            errmsg: string,
        }>

        Request(WeixinWorkRequest: WeixinWorkRequest, params: object): Promise<object>
    }

    class WeixinPayClient {
        constructor(option: WeixinPayOption, ctx: object);

        option: WeixinPayOption;
        ctx: object;
        appid: string;
        mch_id: string;
        key: string;
        app_secret: string;
        cert_path: string;
        key_path: string;
        pfx_path: string;

        objectToXml(obj: object): Promise<string>;

        xmlToObject(xml: string): Promise<object>

        getSign(obj: object): string;

        checkSign(obj: object): boolean;

        execute(WeixinPayRequest: WeixinPayRequest): Promise<object>;
    }

    class WeixinPayRequest {
        constructor(option: WeixinPayOption, ctx: object);

        method: method;
        gatewayUrl: string;
        needSign: boolean;
        needCert: boolean;
        needXml: boolean;
        needJson: boolean;
        parseJson: boolean;
        parseXml: boolean;
        checkSign: boolean;
        content: string;
        configFields: object;
        option: WeixinPayOption;
        ctx: object;
    }

    class WeixinPay {
        constructor(option: object, ctx: object);

        ctx: object;
        option: object;

        PayDownloadbillRequest: Request<{
            appid: string
            mch_id: string
            sub_appid?: string
            sub_mch_id?: string
            nonce_str: string
            sign: string
            sign_type?: 'MD5' | 'HMAC-SHA256'
            bill_date: string
            bill_type?: string
            tar_type?: string
        }, {
            return_code: string
            return_msg: string
        }>;

        PayOrderqueryRequest: Request<{
            appid: string
            sub_appid?: string
            mch_id: string
            sub_mch_id?: string
            transaction_id?: string
            out_trade_no?: string
            nonce_str: string
            sign: string
            sign_type: 'MD5' | 'HMAC-SHA256'
        }, {
            return_code: string
            return_msg: string
            appid: string
            mch_id: string
            nonce_str: string
            sign: string
            result_code: string
            err_code: string
            err_code_des: string
            device_info: string
            openid: string
            is_subscribe: string
            trade_type: string
            trade_state: string
            bank_type: string
            total_fee: string
            settlement_total_fee: string
            fee_type: string
            cash_fee: string
            cash_fee_type: string
            coupon_fee: string
            coupon_count: string
            coupon_type_$n: string
            coupon_id_$n: string
            coupon_fee_$n: string
            transaction_id: string
            out_trade_no: string
            attach: string
            time_end: string
            trade_state_desc: string

        }>;

        PayRefundRequest: Request<{
            appid: string
            mch_id: string
            sub_appid?: string
            sub_mch_id?: string
            nonce_str: string
            sign: string
            sign_type: string
            out_trade_no: string
            out_refund_no: string
            total_fee: string
            refund_fee: string
            refund_fee_type: string
        }, {
            return_code: string
            return_msg: string
            result_code: string
            err_code: string
            err_code_des: string
            appid: string
            mch_id: string
            sub_appid: string
            sub_mch_id: string
            nonce_str: string
            sign: string
            transaction_id: string
            out_trade_no: string
            total_fee: string
            settlement_total_fee: string
            fee_type: string
            cash_fee: string
            refund_count: string
            out_refund_no_$n: string
            refund_id_$n: string
            refund_channel_$n: string
            total_refund_count: string
            refund_fee_$n: string
            settlement_refund_fee_$n: string
            coupon_type_$n_$m: string
            coupon_refund_fee_$n: string
            coupon_refund_count_$n: string
            coupon_refund_id_$n_$m: string
            coupon_refund_fee_$n_$m: string
            refund_status_$n: string
            refund_account_$n: string
            refund_recv_accout_$n: string
            refund_success_time_$n: string
        }>;

        PayRefundqueryRequest: Request<{
            appid: string
            mch_id: string
            sub_appid?: string
            sub_mch_id?: string
            nonce_str: string
            sign: string
            transaction_id?: string
            out_trade_no?: string
            out_refund_no?: string
            refund_id?: string
            offset?: number
        }, {}>;

        PayUnifiedorderRequest: Request<{
            appid: string
            mch_id: string
            sub_appid?: string,
            sub_mch_id?: string
            device_info?: string
            nonce_str: string
            sign: string
            sign_type?: 'MD5' | 'HMAC-SHA256'
            body: string
            detail?: string
            attach?: string
            out_trade_no: string
            fee_type?: string
            total_fee: number
            spbill_create_ip: string
            time_start?: string
            time_expire?: string
            goods_tag?: string
            notify_url: string
            trade_type: string
            product_id?: string
            limit_pay?: string
            openid?: string
            scene_info?: {
                id: string
                name: string
                area_code: string
                address: string
            }
        }, {
            return_code: string
            return_msg: string
            appid: string
            mch_id: string
            sub_appid: string
            sub_mch_id: string
            device_info: string
            nonce_str: string
            sign: string
            result_code: string
            err_code: string
            err_code_des: string
            trade_type: string
            prepay_id: string
            code_url: string
        }>;

        PayCloseorderRequest: Request<{
            appid: string
            mch_id: string
            sub_appid?: string,
            sub_mch_id?: string
            out_trade_no?: string
            nonce_str: string
            sign: string
            sign_type?: 'MD5' | 'HMAC-SHA256'
        }, {
            return_code: string
            return_msg: string
            appid: string
            mch_id: string
            sub_appid: string
            sub_mch_id: string
            nonce_str: string
            sign: string
            err_code: string
            err_code_des: string
        }>;

        PromotionTransfersRequest: Request<{
            mch_appid: string
            mchid: string
            device_info?: string
            nonce_str: string
            sign: string
            partner_trade_no: string
            openid: string
            check_name: 'NO_CHECK' | 'FORCE_CHECK'
            re_user_name?: string
            amount: number
            desc: string
            spbill_create_ip: string
        }, {
            return_code: string
            return_msg: string
            mch_appid: string
            mchid: string
            device_info: string
            nonce_str: string
            result_code: string
            err_code: string
            err_code_des: string
            partner_trade_no: string
            payment_no: string
            payment_time: string
        }>

        SendRedpackRequest: Request<{
            nonce_str: string
            sign: string
            mch_billno: string
            wxappid: string
            msgappid: string
            mch_id: string
            sub_mch_id?: string
            send_name: string
            re_openid: string
            total_amount: number
            total_num: number
            wishing: string
            client_ip: string
            act_name: string
            remark: string
            scene_id?: string | 'PRODUCT_1' | 'PRODUCT_2' | 'PRODUCT_3' | 'PRODUCT_4'
                | 'PRODUCT_5' | 'PRODUCT_6' | 'PRODUCT_7' | 'PRODUCT_8'
            risk_info?: string
            consume_mch_id?: string
        }, {
            return_code: string
            return_msg: string
            result_code: string
            err_code: string
            err_code_des: string
            mch_billno: string
            mch_id: string
            wxappid: string
            re_openid: string
            total_amount: string
            send_listid: string
        }>

        GethbinfoRequest: Request<{
            mch_billno: string
            bill_type: "MCHT"
        }, {
            return_code: string
            return_msg: string
            result_code: string
            err_code: string
            err_code_des: string
            mch_billno: string
            mch_id: string
            detail_id: string
            status: "SENDING" | "SENT" | "FAILED" | "RECEIVED" | "RFUND_ING" | 'REFUND'
            send_type: "API" | "UPLOAD" | "ACTIVITY"
            hb_type: string
            total_num: number
            total_amount: number
            reason: string
            send_time: string
            refund_time: string
            refund_amount: number
            wishing: string
            remark: string
            act_name: string
            hblist: []
            openid: string
            amount: number
            rcv_time: string
        }>

        XmlToObject(xml: string): Promise<object>;

        ObjectToXml(obj: object): Promise<string>;

        GetSign(obj: object): string;

        CheckSign(obj: object): boolean;

        ReturnXml(return_code: "SUCCESS" | string, return_msg: "OK" | string): string

        Request(WeixinPayRequest: WeixinPayRequest, params: object): Promise<object>
    }

    class WeixinMpClient {
        constructor(option: WeixinPayOption, ctx: object);
    }

    class WeixinMpRequest {
        constructor(option: object, ctx: object);

        method: method;
        fields: Array<string>;
        gatewayUrl: string;
        needSign: boolean;
        needCert: boolean;
        needXml: boolean;
        needJson: boolean;
        parseJson: boolean;
        parseXml: boolean;
        params: object;
        content: object;
        option: object;
        ctx: object;
    }

    class WeixinMp {
        constructor(option: object, ctx: object);

        ctx: object;
        option: object;
        AuthorizeRequest: Request<{}, {}>;
        MenuGetRequest: Request<{}, {}>;

        MessageTemplateSendRequest: Request<{
            appid: string,
            access_token: string,
            touser: string,
            template_id: string,
            data: Object
        }, {}>;

        SnsAuth2AccessTokenRequest: Request<{
            appid: string,
            secret: string,
            grant_type: string,
            code: string
        }, {
            errcode: number,
            errmsg: string,
            access_token: string,
            expires_in: number,
            openid: string,
            refresh_token: string
            scope: string
        }>;

        SnsUserinfoRequest: Request<{
            access_token: string,
            openid: string
        }, {
            errcode: number,
            errmsg: string,
            city: string,
            country: string,
            headimgurl: string,
            language: string,
            nickname: string,
            openid: string,
            privilege: Array<string>,
            province: string,
            sex: number
        }>;

        TicketGetTicketRequest: Request<{
            access_token: string,
            type: 'jsapi'
        }, {}>;

        TokenRequest: Request<{
            appid: string,
            secret: string,
            grant_type: 'client_credential'
        }, {
            errcode: number,
            errmsg: string,
            access_token: string,
            expires_in: number
        }>;

        UserGetRequest: Request<{
            access_token: string,
            next_openid?: string
        }, {
            errcode: number,
            errmsg: string,
            total: number,
            count: number,
            data: {
                openid: Array<string>
            },
            next_openid: string
        }>;

        UserInfoRequest: Request<{}, {}>;

        MessageCustomSend: Request<{
            access_token: string
            touser: string
            msgtype: 'text' | 'image' | 'voice' | 'video' | 'music' | 'news' | 'mpnews' | 'wxcard' | 'miniprogrampage'
            text: {
                content: string
            }
            image: {
                media_id: string
            }
            voice: {
                media_id: string
            }
            video: {
                media_id: string,
                thumb_media_id: string,
                title: string,
                description: string
            }
            "music": {
                title: string,
                description: string,
                musicurl: string,
                hqmusicurl: string,
                thumb_media_id: string
            }
            news: {
                articles: Array<{
                    title: string,
                    description: string,
                    url: string,
                    picurl: string
                }>
            }
            msgmenu: {
                head_content: string
                list: Array<{
                    id: string,
                    content: string
                }>,
                tail_content: string
            }
            wxcard: {
                "card_id": string
            }
            miniprogrampage:
                {
                    title: string,
                    appid: string,
                    pagepath: string,
                    thumb_media_id: string
                }
        }, { errcode: number, errmsg: string }>

        SingTicket(params: { jsapi_ticket: string, url: string }): {
            sign: string,
            noncestr: string,
            timestamp: string,
            url: string
        };

        XmlToObject(xml: string): Promise<object>;

        ObjectToXml(obj: object): Promise<string>;

        GetSign(obj: object): string;

        CheckSign(obj: object): boolean;

        Request(request: WeixinMpRequest, params: object): Promise<object>
    }

    class WeixinOpenClient {

    }

    class WeixinOpenRequest {

    }

    class WeixinOpen {
        constructor(option: object, ctx: object);

        ctx: object;
        option: object;

        ApiComponentTokenRequest: Request<{
            errcode: number
            errmsg: string
            component_access_token: string
            expires_in: number
        }, {}>

        ApiCreatePreauthcodeRequest: Request<{
            errcode: number
            errmsg: string
            pre_auth_code: string
            expires_in: number
        }, {}>

        ApiQueryAuthRequest: Request<{
            errcode: number
            errmsg: string
            authorization_info: {
                authorizer_appid: string
                authorizer_access_token: string
                expires_in: number
                authorizer_refresh_token: string
                func_info: Array<{
                    funcscope_category: {
                        id: string
                    }
                }>
            }
        }, {}>
    }
}

export = JinghuanWx